==> xreview_0.96.zip: xreview/language/japanese/quickguide.php <==
<?php

  define("_MB_QUICKGUIDE_LABEL_MODULE","⥸塼̾:");
  define("_MB_QUICKGUIDE_LABEL_VERSION","С:");

  define("_MB_QUICKGUIDE_TITLE","⥸塼복");
  define("_MB_QUICKGUIDE_INFO","ʣо(оݥƥġ)Фʣο(ɾԡ)ˤɾϤٱ礷<br>η̤ޥȥåǰǤ⥸塼Ǥ");

  define("_MB_QUICKGUIDE_QUICK_REF_TITLE","åե");
  define("_MB_QUICKGUIDE_QUICK_REF_INFO","ΣĤμǡоݥƥġ٤ФɾϤX-ReviewǤ褦ˤʤޤ");

	$quick_ref_document_tilte[0] = "1.оݥƥġ٤γǧ";
	$quick_ref_document_tilte[1] = "2.оݥƥġ٤ɾȤ߹";
	$quick_ref_document_tilte[2] = "3.ɾԡ٤ꤹ";
	$quick_ref_document_tilte[3] = "4.إӥ塼åȡ٤ꤹ";

	$quick_ref_document_info[0]  = "оݥƥġ٤ˤڡURLǼ̤Ǥ뤳ȤǧƤ";
	$quick_ref_document_info[1]  = "ӥ塼Ȥ߹ߤڡΥƥץ졼ȤˡΥɤɲäƤ<br>";
	$quick_ref_document_info[1] .= "&lt;&#123;include_php file='file:$xoops_rootpath/modules/xreview/review.php'&#125;&gt;";
	$quick_ref_document_info[2]  = "X-Review⥸塼[<a href='xreview_admin.php?op=authe'></a>]ϤĤ륰롼פꤷƤ";
	$quick_ref_document_info[3]  = "[ӥ塼åȴ]̤[ӥ塼åȿɲ]̤ǡ<br>";
	$quick_ref_document_info[3] .= "ޥȥåǥӥ塼ɽоݥƥ(URI)٤򤷤ơ̾ΤϤɲäƤ";

  define("_MB_QUICKGUIDE_FAQ","ƣ");
	$faq_document_tilte[0] = "ɾʣоݤȤϡ";
	$faq_document_tilte[1] = "ɾʣοͤȤϡ";
	$faq_document_tilte[2] = "ޥȥåȤϡ";

	$faq_document_info[0]  = "ɾоݤȤϡXOOPSΥƥĤˤʤޤ<br>";
	$faq_document_info[0] .= "ƥĤμ̤URLѤƤΤǡURLȽ̤Ǥ륳ƥĤǤɬפޤ<br>";
	$faq_document_info[0] .= "ȤС󥯥⥸塼γƥ󥯤Ǥ<br>";
	$faq_document_info[0] .= "ܥ⥸塼Ǥϡоݥƥġ٤ȸƤӤޤ";
	$faq_document_info[1]  = "X-Review⥸塼[<a href='xreview_admin.php?op=authe'></a>]ϤĤ륰롼פꤷ桼롼פ°桼ɾϤ뤳ȤǤޤ<br>";
	$faq_document_info[1] .= "ܥ⥸塼Ǥϡɾԡ٤ȸƤӤޤ";
	$faq_document_info[2]  = "ļȲˤ줾죲Ĥιܤꤷܤ򺹤ˣĤιܤƤ򤷤᤹<br>";
	$faq_document_info[2] .= "ܥ⥸塼Ǥϡļɾԡ١оݥƥġ٤ȤɽȤߤɽޤ";

	define("_MB_QUICKGUIDE_ADMIN_INFO_TITLE","ǽ");
	$admin_info_document_tilte[0] = "ˤĤ";
	$admin_info_document_tilte[1] = "գңɴˤĤ";
	$admin_info_document_tilte[2] = "ӥ塼åȴˤĤ";

	$admin_info_document_info[0] = "ɾԡ٤ꤹ뤳ȤǤޤ";
	$admin_info_document_info[1] = "оݥƥġΥȺоݥƥġ٤ФɾԽȺǤޤ";
	$admin_info_document_info[2] = "оݥƥġ٤Ȥ߹碌ƥӥ塼åȤ򿷵ɲäꡢ¸Υӥ塼åȤԽȺǤޤ";












?>

==> xreview_0.97.zip: xreview/language/japanese/quickguide.php <==
<?php

  define("_MB_QUICKGUIDE_LABEL_MODULE","⥸塼̾:");
  define("_MB_QUICKGUIDE_LABEL_VERSION","С:");

  define("_MB_QUICKGUIDE_TITLE","⥸塼복");
  define("_MB_QUICKGUIDE_INFO","ʣо(оݥƥġ)Фʣο(ɾԡ)ˤɾϤٱ礷<br>η̤ޥȥåǰǤ⥸塼Ǥ");

  define("_MB_QUICKGUIDE_QUICK_REF_TITLE","åե");
  define("_MB_QUICKGUIDE_QUICK_REF_INFO","ΣĤμǡоݥƥġ٤ФɾϤX-ReviewǤ褦ˤʤޤ");

	$quick_ref_document_tilte[0] = "1.оݥƥġ٤γǧ";
	$quick_ref_document_tilte[1] = "2.оݥƥġ٤ɾȤ߹";
	$quick_ref_document_tilte[2] = "3.ɾԡ٤ꤹ";
	$quick_ref_document_tilte[3] = "4.إӥ塼åȡ٤ꤹ";

	$quick_ref_document_info[0]  = "оݥƥġ٤ˤڡURLǼ̤Ǥ뤳ȤǧƤ";
	$quick_ref_document_info[1]  = "ӥ塼Ȥ߹ߤڡΥƥץ졼ȤˡΥɤɲäƤ<br>";
	$quick_ref_document_info[1] .= "&lt;&#123;include_php file='file:\$xoops_rootpath/modules/xreview/review.php'&#125;&gt;";
	$quick_ref_document_info[2]  = "X-Review⥸塼[<a href='xreview_admin.php?op=authe'></a>]ϤĤ륰롼פꤷƤ";
	$quick_ref_document_info[3]  = "[ӥ塼åȴ]̤[ӥ塼åȿɲ]̤ǡ<br>";
	$quick_ref_document_info[3] .= "ޥȥåǥӥ塼ɽоݥƥ(URI)٤򤷤ơ̾ΤϤɲäƤ";

  define("_MB_QUICKGUIDE_FAQ","ƣ");
	$faq_document_tilte[0] = "ɾʣоݤȤϡ";
	$faq_document_tilte[1] = "ɾʣοͤȤϡ";
	$faq_document_tilte[2] = "ޥȥåȤϡ";

	$faq_document_info[0]  = "ɾоݤȤϡXOOPSΥƥĤˤʤޤ<br>";
	$faq_document_info[0] .= "ƥĤμ̤URLѤƤΤǡURLȽ̤Ǥ륳ƥĤǤɬפޤ<br>";
	$faq_document_info[0] .= "ȤС󥯥⥸塼γƥ󥯤Ǥ<br>";
	$faq_document_info[0] .= "ܥ⥸塼Ǥϡоݥƥġ٤ȸƤӤޤ";
	$faq_document_info[1]  = "X-Review⥸塼[<a href='xreview_admin.php?op=authe'></a>]ϤĤ륰롼פꤷ桼롼פ°桼ɾϤ뤳ȤǤޤ<br>";
	$faq_document_info[1] .= "ܥ⥸塼Ǥϡɾԡ٤ȸƤӤޤ";
	$faq_document_info[2]  = "ļȲˤ줾죲Ĥιܤꤷܤ򺹤ˣĤιܤƤ򤷤᤹<br>";
	$faq_document_info[2] .= "ܥ⥸塼Ǥϡļɾԡ١оݥƥġ٤ȤɽȤߤɽޤ";

	define("_MB_QUICKGUIDE_ADMIN_INFO_TITLE","ǽ");
	$admin_info_document_tilte[0] = "ˤĤ";
	$admin_info_document_tilte[1] = "գңɴˤĤ";
	$admin_info_document_tilte[2] = "ӥ塼åȴˤĤ";

	$admin_info_document_info[0] = "ɾԡ٤ꤹ뤳ȤǤޤ";
	$admin_info_document_info[1] = "оݥƥġΥȺоݥƥġ٤ФɾԽȺǤޤ";
	$admin_info_document_info[2] = "оݥƥġ٤Ȥ߹碌ƥӥ塼åȤ򿷵ɲäꡢ¸Υӥ塼åȤԽȺǤޤ";












?>
